@@ -1,7 +1,7 @@
 package Bencher::Scenario::PERLANCAR::pass_list_vs_array;
 
 our $DATE = '2016-04-13'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -44,7 +44,7 @@ Bencher::Scenario::PERLANCAR::pass_list_vs_array - Benchmark passing list vs arr
 
 =head1 VERSION
 
-This document describes version 0.04 of Bencher::Scenario::PERLANCAR::pass_list_vs_array (from Perl distribution Bencher-Scenarios-PERLANCAR), released on 2016-04-13.
+This document describes version 0.05 of Bencher::Scenario::PERLANCAR::pass_list_vs_array (from Perl distribution Bencher-Scenarios-PERLANCAR), released on 2016-04-13.
 
 =head1 SYNOPSIS
 
@@ -93,30 +93,30 @@ Benchmark with default options (C<< bencher -m PERLANCAR::pass_list_vs_array >>)
  +---------------+-----------+----------+------------+-----------+------------+---------+---------+
  | participant   | arg_reuse | arg_size | rate (/s)  | time (ms) | vs_slowest | errors  | samples |
  +---------------+-----------+----------+------------+-----------+------------+---------+---------+
- | pass_list     | 1000      | 10000    | 50.2       | 19.9      | 1          | 1.6e-05 | 20      |
- | pass_list     | 100       | 10000    | 475        | 2.11      | 9.46       | 2.1e-07 | 20      |
- | pass_list     | 1000      | 1000     | 5.9e+02    | 1.7       | 12         | 1.8e-06 | 21      |
- | pass_list     | 10        | 10000    | 2.64e+03   | 0.379     | 52.6       | 4e-08   | 36      |
- | pass_arrayref | 1000      | 10000    | 3558.64    | 0.281006  | 70.9054    | 4.6e-11 | 20      |
- | pass_list     | 1000      | 100      | 4.4e+03    | 0.227     | 87.6       | 2.1e-07 | 20      |
- | pass_list     | 1         | 10000    | 4.91e+03   | 0.204     | 97.9       | 1.4e-07 | 25      |
- | pass_arrayref | 100       | 10000    | 5.16e+03   | 0.194     | 103        | 5.3e-08 | 20      |
- | pass_list     | 100       | 1000     | 5350.74    | 0.18689   | 106.613    | 3.3e-11 | 20      |
- | pass_arrayref | 10        | 10000    | 5406.96    | 0.184947  | 107.733    | 4.6e-11 | 20      |
- | pass_arrayref | 1         | 10000    | 5436.88    | 0.183929  | 108.3289   | 1.1e-11 | 26      |
- | pass_arrayref | 1000      | 1000     | 8551.333   | 0.1169408 | 170.3838   | 1.1e-11 | 21      |
- | pass_arrayref | 1000      | 100      | 1e+04      | 0.0999    | 199        | 2.7e-08 | 20      |
- | pass_list     | 10        | 1000     | 28204.5    | 0.0354554 | 561.969    | 9.6e-12 | 20      |
- | pass_arrayref | 100       | 1000     | 34873      | 0.028675  | 694.84     | 4.6e-11 | 20      |
- | pass_list     | 100       | 100      | 3.5e+04    | 0.028     | 7e+02      | 4.8e-08 | 38      |
- | pass_list     | 1         | 1000     | 4.8e+04    | 0.021     | 9.5e+02    | 2.5e-08 | 23      |
- | pass_arrayref | 10        | 1000     | 50475      | 0.019812  | 1005.7     | 3.5e-11 | 20      |
- | pass_arrayref | 1         | 1000     | 52839      | 0.018926  | 1052.8     | 4.5e-11 | 20      |
- | pass_arrayref | 100       | 100      | 83826      | 0.01193   | 1670.2     | 3.5e-11 | 20      |
- | pass_list     | 10        | 100      | 2.26e+05   | 0.00442   | 4.51e+03   | 1.4e-09 | 28      |
- | pass_arrayref | 10        | 100      | 3.1718e+05 | 0.0031528 | 6319.7     | 1.1e-11 | 20      |
- | pass_list     | 1         | 100      | 4.192e+05  | 0.002385  | 8353       | 4.6e-11 | 20      |
- | pass_arrayref | 1         | 100      | 4.4201e+05 | 0.0022624 | 8807       | 1.1e-11 | 20      |
+ | pass_list     | 1000      | 10000    | 46         | 22        | 1          | 4.4e-05 | 23      |
+ | pass_list     | 100       | 10000    | 4.4e+02    | 2.3       | 9.5        | 1.1e-05 | 20      |
+ | pass_list     | 1000      | 1000     | 5.9e+02    | 1.7       | 13         | 5.7e-06 | 21      |
+ | pass_list     | 10        | 10000    | 2.48e+03   | 0.403     | 53.4       | 2.1e-07 | 20      |
+ | pass_list     | 100       | 1000     | 3e+03      | 0.33      | 65         | 4.2e-07 | 21      |
+ | pass_arrayref | 1000      | 10000    | 3.4e+03    | 0.29      | 74         | 9.1e-07 | 20      |
+ | pass_list     | 1000      | 100      | 4.17e+03   | 0.24      | 89.6       | 2.1e-07 | 20      |
+ | pass_list     | 1         | 10000    | 4788.26    | 0.208844  | 102.987    | 9.2e-11 | 20      |
+ | pass_arrayref | 100       | 10000    | 4.95e+03   | 0.202     | 106        | 4.9e-08 | 24      |
+ | pass_arrayref | 10        | 10000    | 5.13e+03   | 0.195     | 110        | 5.3e-08 | 20      |
+ | pass_arrayref | 1         | 10000    | 5300.23    | 0.188671  | 113.998    | 0       | 25      |
+ | pass_arrayref | 1000      | 1000     | 8135.48    | 0.122918  | 174.98     | 5.7e-11 | 20      |
+ | pass_arrayref | 1000      | 100      | 9349.71    | 0.106955  | 201.096    | 0       | 20      |
+ | pass_list     | 10        | 1000     | 2.67e+04   | 0.0374    | 575        | 1.3e-08 | 21      |
+ | pass_arrayref | 100       | 1000     | 33701      | 0.029673  | 724.84     | 5.8e-11 | 20      |
+ | pass_list     | 100       | 100      | 3.91e+04   | 0.0256    | 840        | 1.1e-08 | 27      |
+ | pass_list     | 1         | 1000     | 44833      | 0.022305  | 964.28     | 4.6e-11 | 20      |
+ | pass_arrayref | 10        | 1000     | 4.78e+04   | 0.0209    | 1.03e+03   | 6.7e-09 | 20      |
+ | pass_arrayref | 1         | 1000     | 5.13e+04   | 0.0195    | 1.1e+03    | 5.6e-09 | 28      |
+ | pass_arrayref | 100       | 100      | 7.98e+04   | 0.0125    | 1.72e+03   | 5.7e-09 | 27      |
+ | pass_list     | 10        | 100      | 2.248e+05  | 0.004448  | 4835       | 8e-11   | 36      |
+ | pass_arrayref | 10        | 100      | 3.1659e+05 | 0.0031586 | 6809.3     | 1.1e-11 | 27      |
+ | pass_list     | 1         | 100      | 3.962e+05  | 0.002524  | 8521.5     | 1.1e-11 | 20      |
+ | pass_arrayref | 1         | 100      | 4.2e+05    | 0.00238   | 9.04e+03   | 7.5e-10 | 25      |
  +---------------+-----------+----------+------------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
