@@ -1,7 +1,7 @@
 package Bencher::Scenario::PERLANCAR::require;
 
 our $DATE = '2016-04-13'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -75,7 +75,7 @@ Bencher::Scenario::PERLANCAR::require - Benchmark require() in a tight loop/subr
 
 =head1 VERSION
 
-This document describes version 0.04 of Bencher::Scenario::PERLANCAR::require (from Perl distribution Bencher-Scenarios-PERLANCAR), released on 2016-04-13.
+This document describes version 0.05 of Bencher::Scenario::PERLANCAR::require (from Perl distribution Bencher-Scenarios-PERLANCAR), released on 2016-04-13.
 
 =head1 SYNOPSIS
 
@@ -134,10 +134,10 @@ Benchmark with default options (C<< bencher -m PERLANCAR::require >>):
  +--------------------+-----------+-----------+------------+---------+---------+
  | participant        | rate (/s) | time (ns) | vs_slowest | errors  | samples |
  +--------------------+-----------+-----------+------------+---------+---------+
- | require_in_sub     | 2.08e+07  | 48.1      | 1          | 1e-11   | 20      |
- | require_in_sub_pm  | 2.2e+07   | 46        | 1.1        | 4.7e-11 | 31      |
- | require_in_state   | 2e+08     | 5         | 1e+01      | 1.1e-10 | 20      |
- | baseline_empty_sub | 5e+09     | 0.2       | 2e+02      | 4.6e-11 | 20      |
+ | require_in_sub     | 1.9e+07   | 53        | 1          | 2.1e-10 | 20      |
+ | require_in_sub_pm  | 2e+07     | 51        | 1          | 6.9e-11 | 20      |
+ | require_in_state   | 1.1e+08   | 9.1       | 5.8        | 7.8e-11 | 20      |
+ | baseline_empty_sub | 2e+08     | 5         | 1e+01      | 9.2e-11 | 24      |
  +--------------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
